COMPMID-1330: Add support for NormalizePlanarYUV operator in CL

Change-Id: Id0754b9e2bc3ef7ff2c4c21c3b89709588c41bd3
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/146637
Tested-by: Jenkins <bsgcomp@arm.com>
Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Reviewed-by: Giorgio Arena <giorgio.arena@arm.com>
diff --git a/arm_compute/runtime/GLES_COMPUTE/functions/GCNormalizePlanarYUVLayer.h b/arm_compute/runtime/GLES_COMPUTE/functions/GCNormalizePlanarYUVLayer.h
index 2862eeb..d6cf4d0 100644
--- a/arm_compute/runtime/GLES_COMPUTE/functions/GCNormalizePlanarYUVLayer.h
+++ b/arm_compute/runtime/GLES_COMPUTE/functions/GCNormalizePlanarYUVLayer.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017 ARM Limited.
+ * Copyright (c) 2017-2018 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -44,14 +44,26 @@
     GCNormalizePlanarYUVLayer();
     /** Set the input and output tensors.
      *
-     * @param[in]  input  Source tensor. 3 lower dimensions represent a single input with dimensions [width, height, FM].
+     * @param[in]  input  Source tensor. 3 lower dimensions represent a single input with dimensions [width, height, channels].
      *                    Data types supported: F16.
      * @param[out] output Destination tensor. Output will have the same number of dimensions as input. Data type supported: same as @p input
      * @param[in]  mean   Mean values tensor. 1 dimension with size equal to the feature maps [FM]. Data types supported: Same as @p input
      * @param[in]  sd     Standard deviation values tensor. 1 dimension with size equal to the feature maps [FM].
      *                     Data types supported: Same as @p input
      */
-    void configure(const IGCTensor *input, IGCTensor *output, const IGCTensor *mean, const IGCTensor *sd);
+    void configure(const IGCTensor *input, IGCTensor *output, const IGCTensor *mean, const IGCTensor *std);
+    /** Static function to check if given info will lead to a valid configuration of @ref CLNormalizePlanarYUVLayer
+     *
+     * @param[in]  input  Source tensor info. 3 lower dimensions represent a single input with dimensions [width, height, channels].
+     *                    Data types supported: F16/F32.
+     * @param[out] output Destination tensor info. Data type supported: same as @p input
+     * @param[in]  mean   Mean values tensor info. 1 dimension with size equal to the number of input channels. Data types supported: same as @p input
+     * @param[in]  std    Standard deviation values tensor info. 1 dimension with size equal to the number of input channels.
+     *                    Data types supported: same as @p input
+     *
+     * @return a status
+     */
+    static Status validate(const ITensorInfo *input, const ITensorInfo *output, const ITensorInfo *mean, const ITensorInfo *std);
 
     // Inherited methods overridden:
     void run() override;
@@ -44,14 +44,26 @@
      *                    Data types supported: F16.
-     * @param[out] output Destination tensor. Output will have the same number of dimensions as input. Data type supported: same as @p input
-     * @param[in]  mean   Mean values tensor. 1 dimension with size equal to the feature maps [FM]. Data types supported: Same as @p input
-     * @param[in]  sd     Standard deviation values tensor. 1 dimension with size equal to the feature maps [FM].
-     *                     Data types supported: Same as @p input
+     * @param[out] output Destination tensor. Data type supported: same as @p input
+     * @param[in]  mean   Mean values tensor. 1 dimension with size equal to the number of input channels. Data types supported: same as @p input
+     * @param[in]  std    Standard deviation values tensor. 1 dimension with size equal to the number of input channels.
+     *                    Data types supported: same as @p input
      */